| FAOSTAT-package | R Documentation |
Download Data from the FAOSTAT Database of the Food and Agricultural Organization (FAO) of the United Nations. A list of functions to download statistics from FAOSTAT (database of the FAO https://www.fao.org/faostat/) and WDI (database of the World Bank https://data.worldbank.org/), and to perform some harmonization operations.
Maintainer: Paul Rougieux paul.rougieux@gmail.com
Authors:
Michael C. J.
Markus Gesmann
Filippo Gheri
Sebastian Campbell
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.