Usage
getFAOtoSYB(name = NULL, domainCode = "RL", elementCode = 5110,
itemCode = 6621, query, printURL = FALSE, productionDB = FALSE,
useCHMT = TRUE, yearRange = NULL, countrySet = NULL,
outputFormat = c("wide", "long"), returnFlags = FALSE)Arguments
name
The name to be given to the variable.
domainCode
The domain code of the variable, see details.
elementCode
The element code of the variable, see details.
itemCode
The item code of the variable, see details.
query
The object created if using the FAOsearch function
printURL
Whether the url link for the data should be printed
productionDB
Use the production data base
useCHMT
logical, whether the CHMT function should be
outputFormat
The format of the data, can be 'long' or 'wide'.
appied to avoid double counting of China.
returnFlags,
Logical, whether the flags should be
returned. Only work with outputFormat long.
yearRange
A numeric vector containing the years to be downloaded.
countrySet
The FAOSTAT codes of those countries to be downloaded.